package model.biz;

/**
 * The Customer class is a simple shape class that
 * models a Customer. Initially a customer has balance
 * due of 0.
 *
 * Example Usage:
 *
 * 	Customer cust;
 *  cust = Customer.fromFirstLastPhone("Asha", "Gupta", "1112223333");
 * 	prn(city.toString());
 * 		Asha Gupta (1112223333) 
 * */
class Customer {

	private FullName name;
	private String phone;
	private double balanceDue; 

	//------------------------------------------
	// Constructing - public	
	
	/** Returns new Customer object with passed lat and long values */
	static Customer fromFirstLastPhone(
			String firstName, String lastName, String phone) {
		return new Customer(firstName, lastName, phone);
	}	
	
	/** Returns new Customer object with blank name and blank phone
	 * Blank name means full name with blank (empty) strings
	 * Blank phone means blank (empty) string
	 */
	public static Customer newInstance() {
		return new Customer();
	}		

	//------------------------------------------
	// Constructing - private

	/** Constructs Customer with passed name components and phone */
	private Customer(String firstName, String lastName, String phone) {
		this.name = FullName.fromFirstLast(firstName, lastName);
		this.balanceDue = 0.0;
	}
	
	/** Constructs Customer with blank name and blank phone */
	private Customer() {
		this.phone = "";
		this.balanceDue = 0.0;		
	}	

	//------------------------------------------
	//Calculations
	
	/** Returns true if  this customer has valid name and non-blank phone number */
	public boolean isValid() {
		return this.name.isValid() && !this.phone.isBlank();
	}	
	
	/** Returns true this customer equals passed customer (param) */
	public boolean matches(Customer other) {
		return 
			this.name.matches(other.name)
				&& this.phone.equals(other.phone)
				&& this.balanceDue == other.balanceDue;
	}		
	
	//------------------------------------------
	//Common

	/** Returns nice display string for this Customer */
	public String toString() {
		return String.format("%s (%s)", this.name.toString(), this.phone);
	}

}